@@ -14,7 +14,7 @@ from shapely.geometry.collection import GeometryCollection
 from shapely.geometry.base import BaseGeometry
 
 from mundipy.map import Map
-from mundipy.layer import Dataset
+from mundipy.dataset import Dataset
 from mundipy.pcs import choose_pcs, NoProjectionFoundError
 from mundipy.cache import pyproj_transform
 from mundipy.geometry import enrich_geom
@@ -64,7 +64,7 @@ class MundiQ:
             raise TypeError('mundipy.plot() requires mundipy BaseGeometry but got "%s"' % type(shape))
 
         # fix shapes
-        shape = shape.transform('EPSG:4326')._geo
+        shape = shape.as_shapely('EPSG:4326')
         if isinstance(shape, Polygon) or isinstance(shape, MultiPolygon):
             shape = shape.buffer(0)
 
